

set -ex



test -L $PREFIX/lib/libcurand.so.10
test -L $PREFIX/lib/libcurand.so.10.3.5.147
test -L $PREFIX/targets/sbsa-linux/lib/libcurand.so.10
test -f $PREFIX/targets/sbsa-linux/lib/libcurand.so.10.3.5.147
bash test-rpath.sh
exit 0
